﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class HeadersAndFooters : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                // create a new pdf document
                PdfDocument doc = new PdfDocument();
                doc.Margins = new PdfMargins(10, 10, 0, 0);

                // create a new pdf font
                PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
                font.Size = 24;

                // create a new pdf font
                PdfFont font2 = doc.AddFont(PdfStandardFont.Helvetica);
                font2.Size = 12;
                font2.IsUnderline = true;

                // add a new page to the document
                PdfPage page = doc.AddPage();

                // get image path
                string imgFile = AppDomain.CurrentDomain.BaseDirectory + "/../../files/logo.png";

                // header template (100 points in height) with image element
                doc.Header = doc.AddTemplate(doc.Pages[0].ClientRectangle.Width, 100);
                PdfImageElement img1 = new PdfImageElement(0, 0, imgFile);
                doc.Header.Add(img1);

                // footer template (100 points in height) with text element
                doc.Footer = doc.AddTemplate(doc.Pages[0].ClientRectangle.Width, 100);
                PdfTextElement text1 = new PdfTextElement(0, 50,
                    "Footer text: Document generated by Select.Pdf", font2);
                text1.ForeColor = System.Drawing.Color.Blue;
                doc.Footer.Add(text1);

                // create a new text element and add it to the page if page elements are added 
                // after header and footer is set, they will not be displayed in those areas.
                PdfTextElement text = new PdfTextElement(0, 0, Helper.SomeLongText(), font);
                page.Add(text);

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public HeadersAndFooters()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "HeadersAndFooters.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
