﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class PdfViewerPreferences : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                // create a new pdf document
                PdfDocument doc = new PdfDocument();

                // add a new page to the document
                PdfPage page = doc.AddPage();

                // create a new pdf font
                PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
                font.Size = 20;

                // create a new text element and add it to the page
                PdfTextElement text = new PdfTextElement(50, 50,
                    "Select.Pdf for .NET - Pdf Viewer Preferences Sample", font);
                page.Add(text);

                // set the pdf viewer preferences
                doc.ViewerPreferences.CenterWindow = true;
                doc.ViewerPreferences.DisplayDocTitle = true;
                doc.ViewerPreferences.FitWindow = true;
                doc.ViewerPreferences.HideMenuBar = true;
                doc.ViewerPreferences.HideToolbar = true;
                doc.ViewerPreferences.HideWindowUI = false;

                doc.ViewerPreferences.NonFullScreenPageMode =
                    PdfViewerFullScreenExitMode.UseNone;
                doc.ViewerPreferences.PageLayout =
                    PdfViewerPageLayout.SinglePage;
                doc.ViewerPreferences.PageMode =
                    PdfViewerPageMode.UseNone;

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public PdfViewerPreferences()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "PdfViewerPreferences.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
